==> suggest_a_feature-0.2.0.tar.gz: lib/src/presentation/l10n/suggestions_localizations_ru.dart <==
import 'package:suggest_a_feature/src/presentation/l10n/suggestions_localizations.dart';

// ignore_for_file: lines_longer_than_80_chars

/// The translations for Russian (`ru`).
class SuggestionsLocalizationsRu extends SuggestionsLocalizations {
  SuggestionsLocalizationsRu([super.locale = 'ru']);

  @override
  String get suggestion => 'Предложение';

  @override
  String get suggestAFeature => 'Предложить фичу';

  @override
  String get feature => 'Фича';

  @override
  String get bug => 'Баг';

  @override
  String get postedBy => 'Опубликовал:';

  @override
  String get upvote => 'Проголосовать';

  @override
  String get attachedPhotos => 'Прикрепленные фото';

  @override
  String get labels => 'Лейблы';

  @override
  String get notifyMe => 'Уведомить меня';

  @override
  String get notificationDescription => 'Когда это будет сделано';

  @override
  String get save => 'Сохранить';

  @override
  String get edit => 'Редактировать предложение';

  @override
  String get delete => 'Удалить предложение';

  @override
  String get deletionQuestion => 'Вы действительно хотите удалить это предложение?';

  @override
  String get deletionPhotoQuestion => 'Вы действительно хотите удалить это фото?';

  @override
  String get title => 'Кратко опишите ваше предложение';

  @override
  String get description => 'Опишите ваше предложение более подробно';

  @override
  String get postAnonymously => 'Опубликовать анонимно';

  @override
  String get postFromAdmin => 'Опубликовать от имени администратора';

  @override
  String get suggest => 'Предложить';

  @override
  String get status => 'Статус';

  @override
  String get anonymousAuthorName => 'Аноним';

  @override
  String get adminAuthorName => 'Администратор';

  @override
  String get requests => 'Предложения';

  @override
  String get requestsHeader => 'Актуальные предложения';

  @override
  String get requestsDescription => 'Присоединяйтесь к сообществу';

  @override
  String get inProgress => 'В разработке';

  @override
  String get inProgressHeader => 'Предложения в разработке';

  @override
  String get inProgressDescription => 'Скоро появится в приложении';

  @override
  String get completed => 'Реализовано';

  @override
  String get completedHeader => 'Реализованные предложения';

  @override
  String get completedDescription => 'Было реализовано в приложении';

  @override
  String get duplicated => 'Дубликаты';

  @override
  String get duplicatedHeader => 'Продублированные предложения';

  @override
  String get duplicatedDescription => 'Было предложенно ранее';

  @override
  String get declined => 'Отклонено';

  @override
  String get cancelledHeader => 'Отклонённые предложения';

  @override
  String get cancelledDescription => 'Было отклонено';

  @override
  String get savingImageError => 'Ошибка сохранения фото';

  @override
  String get savingImageSuccess => 'Фото успешно сохранено';

  @override
  String get addPhoto => 'Добавить Фото';

  @override
  String get cancel => 'Отмена';

  @override
  String get done => 'Готово';

  @override
  String get yesDelete => 'Да, удалить';

  @override
  String get commentsTitle => 'Комментарии';

  @override
  String get newComment => 'Новый комментарий';

  @override
  String get commentHint => 'Ваш комментарий…';

  @override
  String get publish => 'Опубликовать';

  @override
  String get add => 'Добавить';

  @override
  String get eventPhotosRestriction => 'Вы можете прикрепить до 10 фото 🖼️';
}

==> suggest_a_feature-0.3.0.tar.gz: lib/src/presentation/l10n/suggestions_localizations_ru.dart <==
import 'package:suggest_a_feature/src/presentation/l10n/suggestions_localizations.dart';

// ignore_for_file: lines_longer_than_80_chars

/// The translations for Russian (`ru`).
class SuggestionsLocalizationsRu extends SuggestionsLocalizations {
  SuggestionsLocalizationsRu([super.locale = 'ru']);

  @override
  String get suggestion => 'Предложение';

  @override
  String get suggestAFeature => 'Предложить фичу';

  @override
  String get feature => 'Фича';

  @override
  String get bug => 'Баг';

  @override
  String get postedBy => 'Опубликовал:';

  @override
  String get upvote => 'Проголосовать';

  @override
  String get attachedPhotos => 'Прикрепленные фото';

  @override
  String get labels => 'Лейблы';

  @override
  String get notifyMe => 'Уведомить меня';

  @override
  String get notificationDescription => 'Когда это будет сделано';

  @override
  String get save => 'Сохранить';

  @override
  String get edit => 'Редактировать предложение';

  @override
  String get delete => 'Удалить предложение';

  @override
  String get deletionQuestion =>
      'Вы действительно хотите удалить это предложение?';

  @override
  String get deletionPhotoQuestion =>
      'Вы действительно хотите удалить это фото?';

  @override
  String get title => 'Кратко опишите ваше предложение';

  @override
  String get description => 'Опишите ваше предложение более подробно';

  @override
  String get postAnonymously => 'Опубликовать анонимно';

  @override
  String get postFromAdmin => 'Опубликовать от имени администратора';

  @override
  String get suggest => 'Предложить';

  @override
  String get status => 'Статус';

  @override
  String get anonymousAuthorName => 'Аноним';

  @override
  String get adminAuthorName => 'Администратор';

  @override
  String get requests => 'Предложения';

  @override
  String get requestsHeader => 'Актуальные предложения';

  @override
  String get requestsDescription => 'Присоединяйтесь к сообществу';

  @override
  String get inProgress => 'В разработке';

  @override
  String get inProgressHeader => 'Предложения в разработке';

  @override
  String get inProgressDescription => 'Скоро появится в приложении';

  @override
  String get completed => 'Реализовано';

  @override
  String get completedHeader => 'Реализованные предложения';

  @override
  String get completedDescription => 'Было реализовано в приложении';

  @override
  String get duplicated => 'Дубликаты';

  @override
  String get duplicatedHeader => 'Продублированные предложения';

  @override
  String get duplicatedDescription => 'Было предложенно ранее';

  @override
  String get declined => 'Отклонено';

  @override
  String get cancelledHeader => 'Отклонённые предложения';

  @override
  String get cancelledDescription => 'Было отклонено';

  @override
  String get savingImageError => 'Ошибка сохранения фото';

  @override
  String get savingImageSuccess => 'Фото успешно сохранено';

  @override
  String get addPhoto => 'Добавить Фото';

  @override
  String get cancel => 'Отмена';

  @override
  String get done => 'Готово';

  @override
  String get yesDelete => 'Да, удалить';

  @override
  String get commentsTitle => 'Комментарии';

  @override
  String get newComment => 'Новый комментарий';

  @override
  String get commentHint => 'Ваш комментарий…';

  @override
  String get publish => 'Опубликовать';

  @override
  String get add => 'Добавить';

  @override
  String get eventPhotosRestriction => 'Вы можете прикрепить до 10 фото 🖼️';

  @override
  String get sortBy => 'Сортировать по';

  @override
  String get numberOfLikes => 'Количеству лайков';

  @override
  String get creationDate => 'Дате создания';
}
